.. smote_variants documentation master file, created by
   sphinx-quickstart on Tue Dec 11 21:50:12 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to smote_variants's documentation!
==========================================

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   getting_started
   installation
   
.. toctree::
   :maxdepth: 1
   :caption: API
   
   oversamplers
   noise_filters
   model_selection
   multiclass_oversampling
   
.. toctree::
   :maxdepth: 1
   :caption: Usage
   
   examples
   add_new_oversampler
   gallery

.. toctree::
   :maxdepth: 1
   :caption: Interfaces
   
   use_in_r
   use_in_julia

.. toctree::
   :maxdepth: 1
   :caption: The competition
   
   competition
   ranking
   
.. toctree::
   :maxdepth: 1
   :caption: Downloads

   downloads

.. toctree::
   :maxdepth: 1
   :caption: Additional Information
   
   contribute
   release_history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
